/*
 * $Id: dummy_ci.h,v 1.3 1999/03/20 16:33:34 grubba Exp $
 *
 * Fallback case_info file.
 * Only ISO-8859-1 in this one.
 *
 * Henrik Grubbstrm 1999-03-20
 */
{ 0x0000, CIM_NONE, 0x0000, },
{ 0x0041, CIM_CASEBIT, 0x0020, },
{ 0x005b, CIM_NONE, 0x0000, },
{ 0x0061, CIM_CASEBIT, 0x0020, },
{ 0x007b, CIM_NONE, 0x0000, },
{ 0x00c0, CIM_CASEBIT, 0x0020, },
{ 0x00d7, CIM_NONE, 0x0000, },
{ 0x00d8, CIM_CASEBIT, 0x0020, },
{ 0x00df, CIM_NONE, 0x0000, },
{ 0x00e0, CIM_CASEBIT, 0x0020, },
{ 0x00f7, CIM_NONE, 0x0000, },
{ 0x00f8, CIM_CASEBIT, 0x0020, },
{ 0x00ff, CIM_LOWERDELTA, -0x0079, },
{ 0x0100, CIM_NONE, 0x0000, },
